DroneBlocks Tello Web

## Status

- ###### Battery:

  [[battery_level]]

- ###### Height:

  [[height]]

- ###### Temperature(C):

  [[temp]]

- ###### Flight Time:

  [[flight_time]]

- ###### Flying Speed

- ###### Fly Distance:

## TakeOff and Land

## Fixed Distance Operations

## Flip Operations

# Tello Talent

Operations specific to the Tello Talent

## Top LED

- ###### Red:

- ###### Green:

- ###### Blue:

- ###### Red 2:

- ###### Green 2:

- ###### Blue 2:

- ###### Mode

  Color
  Pulse
  Flash

- ###### Flash/Pulse Freq

## Display Image

- ###### Brightness

- ###### Display Color

  Purple
  Red
  Blue

- ###### Heart

- ###### Happy Face

- ###### Sad Face

- ###### Clear Display

## Scroll Text

- ###### Text:

- ###### Image String:

- ###### Image String

- ###### Clear Display

## Mission Pads

- [[mission_pad_label]]

- ###### Detected Mission Pad:

  [[detected_mission_pad]]

- ###### X:

  [[current_x]]

- ###### Y:

  [[current_y]]

- ###### Z:

  [[current_z]]